@@ -3,7 +3,7 @@
 :organization: Logilab
 :copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: General Public License version 2 - http://www.gnu.org/licenses
+:license: Lesser General Public License version 2 - http://www.gnu.org/licenses
 """
 __docformat__ = "restructuredtext en"
 
@@ -520,8 +520,7 @@ class EntitySchema(PermissionMixIn, ERSchema):
             # check arbitrary constraints
             for constraint in rdef.constraints:
                 if not constraint.check(entity, rschema, value):
-                    errors[qname] = _('%(cstr)s constraint failed for value %(value)r') % {
-                        'cstr': constraint, 'value': value}
+                    errors[qname] = constraint.failed_message(value, _)
         if errors:
             raise ValidationError(entity, errors)
 
