@@ -3,6 +3,7 @@
 
 from logilab.common.testlib import TestCase, unittest_main
 
+from copy import copy, deepcopy
 from tempfile import mktemp
 
 from yams.buildobjs import register_base_types, EntityType, RelationType, RelationDefinition
@@ -58,20 +59,19 @@ class BaseSchemaTC(TestCase):
             except KeyError:
                 schema.add_relation_type(RelationType(_type))
             schema.add_relation_def(RelationDefinition(_from, _type, _to, order=i))
-        schema.rschema('nom').set_rproperty('Person', 'String', 'cardinality','11') # not null
+        schema.rschema('nom').rdef('Person', 'String').cardinality = '11' # not null
 
-        enote.set_rproperty('type', 'constraints',
-                             [StaticVocabularyConstraint((u'bon', u'pasbon',
-                                                                  u'bof', u'peux mieux faire'))])
-        enote.set_rproperty('date', 'cardinality', '11')
+        enote.rdef('type').constraints = [StaticVocabularyConstraint((u'bon', u'pasbon',
+                                                                      u'bof', u'peux mieux faire'))]
+        enote.rdef('date').cardinality = '11'
 
-        eaffaire.set_rproperty('sujet', 'constraints', [SizeConstraint(128)])
-        eaffaire.set_rproperty('ref', 'constraints', [SizeConstraint(12), RegexpConstraint(r'[A-Z]+\d+')])
-        eperson.set_rproperty('nom', 'constraints', [SizeConstraint(20, 10)])
-        eperson.set_rproperty('prenom', 'constraints', [SizeConstraint(64)])
-        eperson.set_rproperty('tel', 'constraints', [IntervalBoundConstraint(maxvalue=999999)])
-        eperson.set_rproperty('fax', 'constraints', [IntervalBoundConstraint(minvalue=12, maxvalue=999999)])
-        eperson.set_rproperty('promo', 'constraints', [StaticVocabularyConstraint( (u'bon', u'pasbon'))])
+        eaffaire.rdef('sujet').constraints = [SizeConstraint(128)]
+        eaffaire.rdef('ref').constraints = [SizeConstraint(12), RegexpConstraint(r'[A-Z]+\d+')]
+        eperson.rdef('nom').constraints = [SizeConstraint(20, 10)]
+        eperson.rdef('prenom').constraints = [SizeConstraint(64)]
+        eperson.rdef('tel').constraints = [IntervalBoundConstraint(maxvalue=999999)]
+        eperson.rdef('fax').constraints = [IntervalBoundConstraint(minvalue=12, maxvalue=999999)]
+        eperson.rdef('promo').constraints = [StaticVocabularyConstraint( (u'bon', u'pasbon'))]
 
         estring = schema.eschema('String')
         eint = schema.eschema('Int')
@@ -159,7 +159,6 @@ class EntitySchemaTC(BaseSchemaTC):
         self.assertListEquals(l, ['Affaire', 'Note', 'Person', 'Societe'])
 
     def test_hash(self):
-        from copy import copy
         d = {}
         d[eperson] = 'p'
         d[enote] = 'n'
@@ -175,17 +174,15 @@ class EntitySchemaTC(BaseSchemaTC):
         self.failUnlessEqual(d[copy(enote)], 'Note')
 
     def test_deepcopy_with_regexp_constraints(self):
-        from copy import deepcopy
-        eaffaire.set_rproperty('ref', 'constraints', [RegexpConstraint(r'[A-Z]+\d+')])
-        rgx_cstr, = eaffaire.constraints('ref')
+        eaffaire.rdef('ref').constraints = [RegexpConstraint(r'[A-Z]+\d+')]
+        rgx_cstr, = eaffaire.rdef('ref').constraints
         eaffaire2 = deepcopy(schema).eschema('Affaire')
-        rgx_cstr2, = eaffaire2.constraints('ref')
+        rgx_cstr2, = eaffaire2.rdef('ref').constraints
         self.assertEquals(rgx_cstr2.regexp, rgx_cstr.regexp)
         self.assertEquals(rgx_cstr2.flags, rgx_cstr.flags)
         self.assertEquals(rgx_cstr2._rgx, rgx_cstr._rgx)
 
     def test_deepcopy(self):
-        from copy import deepcopy
         global schema
         schema = deepcopy(schema)
         self.failIf(eperson is schema['Person'])
@@ -193,6 +190,10 @@ class EntitySchemaTC(BaseSchemaTC):
         self.failUnlessEqual('Person', schema['Person'])
         self.failUnlessEqual(eperson.subject_relations(), schema['Person'].subject_relations())
         self.failUnlessEqual(eperson.object_relations(), schema['Person'].object_relations())
+        self.assertEquals(schema.eschema('Person').final, False)
+        self.assertEquals(schema.eschema('String').final, True)
+        self.assertEquals(schema.rschema('ref').final, True)
+        self.assertEquals(schema.rschema('concerne').final, False)
 
     def test_deepcopy_specialization(self):
         schema2 = deepcopy(SchemaLoader().load([self.datadir], 'Test'))
@@ -203,13 +204,13 @@ class EntitySchemaTC(BaseSchemaTC):
         self.assertEquals(edivision.specialized_by(), [])
 
     def test_is_final(self):
-        self.assertEquals(eperson.is_final(), False)
-        self.assertEquals(enote.is_final(), False)
-        self.assertEquals(estring.is_final(), True)
-        self.assertEquals(eint.is_final(), True)
-        self.assertEquals(eperson.subject_relation('nom').is_final(), True)
+        self.assertEquals(eperson.final, False)
+        self.assertEquals(enote.final, False)
+        self.assertEquals(estring.final, True)
+        self.assertEquals(eint.final, True)
+        self.assertEquals(eperson.subjrels['nom'].final, True)
         #self.assertEquals(eperson.is_final('concerne'), False)
-        self.assertEquals(eperson.subject_relation('concerne').is_final(), False)
+        self.assertEquals(eperson.subjrels['concerne'].final, False)
 
     def test_is_metadata(self):
         self.assertEquals(eperson.is_metadata('promo'), None)
@@ -220,25 +221,24 @@ class EntitySchemaTC(BaseSchemaTC):
 
     def test_defaults(self):
         self.assertEquals(list(eperson.defaults()), [])
-        self.assertRaises(AssertionError,
-                          estring.defaults().next)
+        self.assertRaises(StopIteration, estring.defaults().next)
 
     def test_vocabulary(self):
-        self.assertEquals(eperson.vocabulary('promo'), ('bon', 'pasbon'))
-        self.assertRaises(KeyError,
-                          eperson.vocabulary, 'what?')
-        self.assertRaises(AssertionError,
-                          eperson.vocabulary, 'nom')
+        #self.assertEquals(eperson.vocabulary('promo')
+        self.assertEquals(eperson.rdef('promo').constraint_by_interface(IVocabularyConstraint).vocabulary(),
+                          ('bon', 'pasbon'))
+        # self.assertRaises(AssertionError,
+        #                   eperson.vocabulary, 'nom')
 
     def test_indexable_attributes(self):
-        eperson.set_rproperty('nom', 'fulltextindexed', True)
-        eperson.set_rproperty('prenom', 'fulltextindexed', True)
+        eperson.rdef('nom').fulltextindexed = True
+        eperson.rdef('prenom').fulltextindexed = True
         self.assertEquals(list(eperson.indexable_attributes()), ['nom', 'prenom'])
 
 
     def test_goodValues_relation_default(self):
         """check good values of entity does not raise an exception"""
-        eperson.set_rproperty('nom', 'default', 'No name')
+        eperson.rdef('nom').default = 'No name'
         self.assertEquals(eperson.default('nom'), 'No name')
 
     def test_subject_relations(self):
@@ -258,14 +258,15 @@ class EntitySchemaTC(BaseSchemaTC):
         self.assertEquals(rels, expected)
         rels = [schem.type for schem in eaffaire.object_relations()]
         self.assertEquals(rels, expected)
-        self.assertEquals(eaffaire.object_relation('concerne').type,
+        self.assertEquals(eaffaire.objrels['concerne'].type,
                          'concerne')
 
     def test_destination_type(self):
         """check subject relations a returned in the same order as in the
         schema definition"""
         self.assertEquals(eperson.destination('nom'), 'String')
-        self.assertRaises(AssertionError, eperson.destination, 'travaille')
+        #self.assertRaises(AssertionError, eperson.destination, 'concerne')
+        self.assertEquals(eperson.destination('travaille'), 'Societe')
 
 
 class RelationSchemaTC(BaseSchemaTC):
@@ -281,7 +282,6 @@ class RelationSchemaTC(BaseSchemaTC):
         self.failUnless(rconcerne != rnom)
 
     def test_hash(self):
-        from copy import copy
         d = {}
         d[rconcerne] = 'p'
         d[rnom] = 'n'
@@ -361,8 +361,8 @@ class SchemaTC(BaseSchemaTC):
         self.assertRaisesMsg(BadSchemaDefinition, "using unknown type 'Afire' in relation evaluee"  ,
                              schema.add_relation_def, RelationDefinition('Afire', 'evaluee', 'Note'))
 ## XXX what is this ?
-##        self.assertRaisesMsg(BadSchemaDefinition, 'the "symetric" property should appear on every definition of relation evaluee' ,
-##                             schema.add_relation_def, RelationDefinition('Affaire', 'evaluee', 'Note', symetric=True))
+##        self.assertRaisesMsg(BadSchemaDefinition, 'the "symmetric" property should appear on every definition of relation evaluee' ,
+##                             schema.add_relation_def, RelationDefinition('Affaire', 'evaluee', 'Note', symmetric=True))
 
     def test_schema_relations(self):
         all_relations = ['TEST', 'concerne', 'travaille', 'evaluee',
@@ -374,8 +374,8 @@ class SchemaTC(BaseSchemaTC):
         relations.sort()
         self.assertEquals(relations, all_relations)
 
-        self.assertEquals(len(eperson.rproperty('nom', 'constraints')), 1)
-        self.assertEquals(len(eperson.rproperty('prenom', 'constraints')), 1)
+        self.assertEquals(len(eperson.rdef('nom').constraints), 1)
+        self.assertEquals(len(eperson.rdef('prenom').constraints), 1)
 
     def test_schema_check_relations(self):
         """test behaviour with some incorrect relations"""
@@ -421,7 +421,7 @@ class SchemaTC(BaseSchemaTC):
 
     def test_rename_entity_type(self):
         affaire = schema.eschema('Affaire')
-        orig_rprops = affaire.rproperties('concerne')
+        orig_rprops = affaire.rdef('concerne')
         schema.rename_entity_type('Affaire', 'Workcase')
         self.assertUnorderedIterableEquals(schema._entities.keys(),
                              ['Boolean', 'Bytes', 'Date', 'Datetime', 'Float',
@@ -434,7 +434,7 @@ class SchemaTC(BaseSchemaTC):
         self.assertRaises(KeyError, schema.eschema, 'Affaire')
         workcase = schema.eschema('Workcase')
         schema.__test__ = True
-        self.assertEquals(workcase.rproperties('concerne'), orig_rprops)
+        self.assertEquals(workcase.rdef('concerne'), orig_rprops)
 
 
 class SymetricTC(TestCase):
@@ -444,7 +444,7 @@ class SymetricTC(TestCase):
         ebug = schema.add_entity_type(EntityType('Bug'))
         estory = schema.add_entity_type(EntityType('Story'))
         eproject = schema.add_entity_type(EntityType('Project'))
-        schema.add_relation_type(RelationType('see_also', symetric=True))
+        schema.add_relation_type(RelationType('see_also', symmetric=True))
 
     def test_association_types(self):
         schema.add_relation_def(RelationDefinition('Bug', 'see_also', 'Bug'))
